xeus: C++ implementation of the Jupyter Kernel protocol
=======================================================

Description
-----------

xeus is a library meant to facilitate the implementation of kernels for Jupyter.


License
-------

BSD-3-Clause license


Upstream Contact
----------------

https://github.com/jupyter-xeus/xeus
